@@ -231,14 +231,13 @@ void command_property(gpointer callback_data,guint callback_action,
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
 	ft.margin=ptw->margin;
 	ft.tab=ptw->tab;
-	ft.backup=ptw->backup;
 	ft.code=ptw->code;
 	ft.crlf=ptw->crlf;
 	ft.eof=ptw->eof;
-	ft.grid=ptw->grid;
 	ft.limit=ptw->limit;
 	ft.overwrite=ptw->overwrite;
 	ft.space=ptw->space;
+	ft.gline=ptw->gline;
 	ft.mline=ptw->mline;
 	ft.uline=ptw->uline;
 	ft.vline=ptw->vline;
@@ -256,14 +255,13 @@ void command_property(gpointer callback_data,guint callback_action,
 							&& (ptw->tab!=ft.tab || ptw->margin!=ft.margin));
 		ptw->margin=ft.margin;
 		ptw->tab=ft.tab;
-		ptw->backup=ft.backup;
 		ptw->code=ft.code;
 		ptw->crlf=ft.crlf;
 		ptw->eof=ft.eof;
-		ptw->grid=ft.grid;
 		ptw->limit=ft.limit;
 		ptw->overwrite=ft.overwrite;
 		ptw->space=ft.space;
+		ptw->gline=ft.gline;
 		ptw->mline=ft.mline;
 		ptw->uline=ft.uline;
 		ptw->vline=ft.vline;
@@ -621,7 +619,7 @@ void command_next(gpointer callback_data,guint callback_action,
 				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
 	find_operation(ptw,&ptw->cursor,&ptw->select,find_text[0],
-												find_arrow,find_ignorecase);
+					callback_action==0?find_arrow:!find_arrow,find_ignorecase);
 	if (userbreak && ptw->select.x<0) {
 		text=g_strdup_printf(_("'%s'Ĥޤ"),find_text[0]);
 		message_box("Text maid",text,0,_("λ"),NULL);
