@@ -213,7 +213,7 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 	ptw->cursor.x=get_align_pos(&ptw->start,&ptw->off,
 								ptw->cursor.x,ptw->cursor.y,ptw->tab,FALSE);
 	length0=strlen(find);
-	text=g_malloc(length0*sizeof(gchar));
+	text=g_malloc((length0+1)*sizeof(gchar));
 	if (ptw->select.x>=0) {
 		/* ϰϤ */
 		select=ptw->select;
@@ -223,7 +223,7 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 	if (ed.x>=0) {
 		/* ̤ˤΤȤˤ̵ */
 		i=get_sel_byte(&ptw->start,&ptw->off,&st,&ed,ptw->tab);
-		if (i<length0) {
+		if (i<=length0) {
 			cpy_sel_mem(&ptw->start,&ptw->off,&st,&ed,ptw->tab,text);
 			text[i]='\0';
 			if (ignorecase)	/* ʸ/ʸ̤ */
