@@ -163,7 +163,7 @@ static void property_dialog_clicked_ftype(GtkWidget *widget,gpointer user_data)
 
 	if (ftype_dialog(&pos)) {
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),
-															ftype[pos].grid);
+															ftype[pos].gline);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),
 															ftype[pos].space);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check2),
@@ -204,7 +204,7 @@ static void property_dialog_clicked_ok(GtkWidget *widget,FTYPE *ft)
 	}
 	ft->margin=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin0));
 	ft->tab=gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin1));
-	ft->grid=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check0));
+	ft->gline=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check0));
 	ft->space=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check1));
 	ft->crlf=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check2));
 	ft->mline=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check3));
@@ -291,7 +291,7 @@ gboolean property_dialog(FTYPE *ft)
 	check8=gtk_check_button_new_with_label(
 										_("եκǸ^Z(1A)դ"));
 	check9=gtk_check_button_new_with_label(_("¸ǧ"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),ft->grid);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),ft->gline);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),ft->space);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check2),ft->crlf);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check3),ft->mline);
